## Version 0.0.29

This version includes a number of new features, improvements, and bug fixes. The main focus of this release was to enhance the testing environment, improve code generation, and add new functionalities.

### New Features

- Added float_to_top = true for isort in pyproject.toml config (0c58f8) (Eric Ma)
- Added tests for doc_processor (d679a0) (Eric Ma)
- Modified prompt to ensure that docstring indentation is done correctly (1b1ade) (Eric Ma)
- Added functions replace_object_in_file and insert_docstring (adf44a) (Eric Ma)
- Added dummy module for experimentation purposes (f27a71) (Eric Ma)
- Added validation of chunk_overlap value (9d2070) (Eric Ma)
- Added tests for get_valid_input (0a984b) (Eric Ma)
- Added comment (511953) (Eric Ma)
- Added tests for recorder (f38341) (Eric Ma)
- Added tests for file_finder.py (cfc296) (Eric Ma)
- Added testwriting functionality (435aa4) (Eric Ma)
- Added python dotenv to pyproject.toml (0339c2) (Eric Ma)
- Added more testing deps into the environment (b6bd32) (Eric Ma)
- Added pytest to gh bare testing env (bef9a6) (Eric Ma)

### Bug Fixes

- Fixed type hint based on test (8864e0) (Eric Ma)
- Changed python test version to 3.11 (b4bb40) (Eric Ma)

### Deprecations

- Got rid of typer-cli (b7a187) (Eric Ma)
- Removed requirements.txt build step (27eea3) (Eric Ma)
- Removed call test (0578cf) (Eric Ma)
- Removed model testing (28e8bd) (Eric Ma)

### Improvements

- Bumped version from 0.0.28 to 0.0.29 (ad955c) (Eric Ma)
- Minor changes to Python code generation CLI (3663f8) (Eric Ma)
- Manually installed testing dependencies (44b3de) (Eric Ma)
- Ensured bare environment has all optional dependencies installed (8118c1) (Eric Ma)
- Ensured typer version minimum 0.4.0 in pyproject.toml (8403ad) (Eric Ma)
- Updated environment.yml to pin typer to greater than 0.4.0 (0804a8) (Eric Ma)
- Ensured test ghostwriter has access to bigger file context (5ae1e6) (Eric Ma)
- Modified tests prompt (db9e19) (Eric Ma)
- Changed test prompt (41a46e) (Eric Ma)
- Upgraded docstring (e83505) (Eric Ma)
- Added more explicit validation checks on the presence of the openai API key (d1c508) (Eric Ma)
- Specified object type for markdown_object (4d3782) (Eric Ma)
- Upgraded python to 3.11 (55e457) (Eric Ma)
- Tried out github actions matrix (bc5360) (Eric Ma)
- Ensured tests run on all pushes to main (23c506) (Eric Ma)
- Changed version of panel and bokeh (bfeac4) (Eric Ma)
